# Retrieving SBOM Library Components for Business Applications
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/retrieving-sbom-library-components-for-business-applications#overview)
  * [Use Cases](https://help.sap.com/docs/leanix/ea/retrieving-sbom-library-components-for-business-applications#use-cases)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/retrieving-sbom-library-components-for-business-applications#prerequisites)
  * [Endpoint](https://help.sap.com/docs/leanix/ea/retrieving-sbom-library-components-for-business-applications#endpoint)
  * [MCP Tool](https://help.sap.com/docs/leanix/ea/retrieving-sbom-library-components-for-business-applications#mcp-tool)
  * [Related Information](https://help.sap.com/docs/leanix/ea/retrieving-sbom-library-components-for-business-applications#related-information)


Get SBOM library components for a business application using the REST API endpoint or the MCP tool for integration with AI agents.
